==========
Enrich SDK
==========

Enrich is a customizable, privacy law-aware enterprise Feature Store
of `Scribble Data`_. This SDK is part of the feature store stack. It
enables local development, testing and documentation of simple to
complex feature transformations and other modules required for
building and managing robust features.

This is not for general purpose use. Please get in touch with us at
hello@scribbledata.io to discuss potential use of this SDK. 

For enterprise users of Enrich, the documentation is available on the
server. Please see the Developer section.

.. _Scribble Data: https://www.scribbledata.io


